#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

package Vhffs::Robots::Bazaar;

use Vhffs::Services::Bazaar;
use Vhffs::Constants;
use Vhffs::Functions;

sub create_repo
{
	my $bazaar = shift;
	return -1 unless defined $bazaar;
	return -1 if $bazaar->get_status != Vhffs::Constants::WAITING_FOR_CREATION;

	my $dir = $bazaar->get_dir;

	if( -e $dir ) {
		$bazaar->set_status( Vhffs::Constants::CREATING_ERROR );
		$bazaar->commit();
		$bazaar->add_history('Error, directory of this bazaar repository already exists! Administrators must fix the problem.');
		return -1;
	}

	Vhffs::Functions::create_dir( $dir );
	Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
	Vhffs::Functions::change_owner_recur( $dir , $bazaar->get_owner_uid , $bazaar->get_owner_gid );
	$bazaar->add_history('Ok, robots find the empty directory and will create bazaar repository');

	system('cd '.$dir.' && bzr init > /dev/null');

	unless( -d $dir.'/.bzr' ) {
		$bazaar->set_status( Vhffs::Constants::CREATING_ERROR );
		$bazaar->commit();
		$bazaar->add_history('Error, nothing was created after calling the bazaar binary, something is wrong.');
		return -1;
	}

	Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
	Vhffs::Functions::change_owner_recur( $dir , $bazaar->get_owner_uid , $bazaar->get_owner_gid );

	$bazaar->add_history('The Robots created the bazaar repository');
	$bazaar->set_status( Vhffs::Constants::ACTIVATED );
	$bazaar->commit;

	return 0;
}

sub change_conf {
	my $bazaar = shift;
	return -1 unless defined $bazaar;

	my $dir = $bazaar->get_dir;
	my $mail_from = $bazaar->get_main->get_config->get_service('bazaar')->{notify_from};

	if( $bazaar->get_ml_name !~ /^\s*$/ ) {
	}

	return 0;
}

sub delete_repo
{
	use File::Path;
	use File::Basename;
	my $bazaar = shift;
	return -1 unless defined $bazaar;

	# Remove Bazaar dir and group dir if empty
	my $dir = $bazaar->get_dir;
	File::Path::rmtree($dir) if(-d $dir);
	my $groupdir = dirname($dir);
	rmdir($groupdir);

	return 0;
}


1;
